@@ -5,6 +5,7 @@ from .state_door import StateDoor
 from .state_general import StateGeneral
 from .state_light import StateLight
 from .state_feeder import StateFeeder
+from .state_fan import StateFan
 
 @dataclass
 class State:
@@ -13,6 +14,7 @@ class State:
     door: Optional[StateDoor] = None
     light: Optional[StateLight] = None
     feeder: Optional[StateFeeder] = None
+    fan: Optional[StateFan] = None
 
     @staticmethod
     def from_json(json_data: Any) -> 'State':
@@ -21,5 +23,6 @@ class State:
             connectivity=StateConnectivity.from_json(json_data['connectivity']),
             door=StateDoor.from_json(json_data['door']) if json_data.get('door') else None,
             light=StateLight.from_json(json_data['light']) if json_data.get('light') else None,
-            feeder=StateFeeder.from_json(json_data['feeder']) if json_data.get('feeder') else None
+            feeder=StateFeeder.from_json(json_data['feeder']) if json_data.get('feeder') else None,
+            fan=StateFan.from_json(json_data['fan']) if json_data.get('fan') else None
         )
